@@ -32,9 +32,8 @@ class Product:
 
 
 class Costumer:
-    def __init__(self, number, name, email, tax_number, address, postal_code, city, country="PT",):
+    def __init__(self, name, email, tax_number, address, postal_code, city, country="PT",):
 
-        self.number = number
         self.name = name
         self.email = email
         self.tax_number = tax_number
@@ -45,7 +44,6 @@ class Costumer:
 
     def to_dict(self):
         costumer_dict = {
-            "number": self.number,
             "name": self.name,
             "address": self.address,
             "postalCode": self.postal_code,
@@ -70,7 +68,7 @@ class Invoice:
                 "option": 1
             },
             "document": {
-                "docType": 1
+                "docType": 2
             },
             "products": [
                 p.to_dict() for p in self.products
